<?php

namespace Lavalite\Stock\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Stock\Models\Stock;

class StockPolicy
{

    /**
     * Determine if the given user can view the stock.
     *
     * @param UserPolicy $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function view(UserPolicy $user, Stock $stock)
    {
        if ($user->canDo('stock.stock.view') && $user->isAdmin()) {
            return true;
        }

        return $stock->user_id == user_id() && $stock->user_type == user_type();
    }

    /**
     * Determine if the given user can create a stock.
     *
     * @param UserPolicy $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('stock.stock.create');
    }

    /**
     * Determine if the given user can update the given stock.
     *
     * @param UserPolicy $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function update(UserPolicy $user, Stock $stock)
    {
        if ($user->canDo('stock.stock.edit') && $user->isAdmin()) {
            return true;
        }

        return $stock->user_id == user_id() && $stock->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given stock.
     *
     * @param UserPolicy $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Stock $stock)
    {
        return $stock->user_id == user_id() && $stock->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given stock.
     *
     * @param UserPolicy $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Stock $stock)
    {
        if ($user->canDo('stock.stock.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given stock.
     *
     * @param UserPolicy $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Stock $stock)
    {
        if ($user->canDo('stock.stock.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
